@@ -21,8 +21,6 @@ import time
 import datetime
 import xml.dom.minidom
 
-import iso8601
-
 from starcluster import utils
 from starcluster import static
 from starcluster import exception
@@ -39,13 +37,14 @@ class SGEStats(object):
     """
     SunGridEngine stats parser
     """
-    def __init__(self):
+    def __init__(self, remote_tzinfo=None):
         self.jobstat_cachesize = 200
         self.hosts = []
         self.jobs = []
         self.queues = {}
         self.jobstats = self.jobstat_cachesize * [None]
         self.max_job_id = 0
+        self.remote_tzinfo = remote_tzinfo or utils.get_utc_now().tzinfo
 
     @property
     def first_job_id(self):
@@ -136,7 +135,7 @@ class SGEStats(object):
         Tue Jul 13 16:24:03 2010
         """
         dt = datetime.datetime.strptime(qacct, "%a %b %d %H:%M:%S %Y")
-        return dt.replace(tzinfo=iso8601.iso8601.UTC)
+        return dt.replace(tzinfo=self.remote_tzinfo)
 
     def parse_qacct(self, string, dtnow):
         """
@@ -212,7 +211,7 @@ class SGEStats(object):
         """
         returns a count of the hosts in the cluster
         """
-        #todo: throw an exception if hosts not initialized
+        # todo: throw an exception if hosts not initialized
         return len(self.hosts)
 
     def count_total_slots(self):
@@ -252,8 +251,8 @@ class SGEStats(object):
             if 'JB_submission_time' in j:
                 st = j['JB_submission_time']
                 dt = utils.iso_to_datetime_tuple(st)
-                return dt
-        #todo: throw a "no queued jobs" exception
+                return dt.replace(tzinfo=self.remote_tzinfo)
+        # todo: throw a "no queued jobs" exception
 
     def is_node_working(self, node):
         """
@@ -322,21 +321,21 @@ class SGEStats(object):
     def get_all_stats(self):
         now = utils.get_utc_now()
         bits = []
-        #first field is the time
+        # first field is the time
         bits.append(now)
-        #second field is the number of hosts
+        # second field is the number of hosts
         bits.append(self.count_hosts())
-        #third field is # of running jobs
+        # third field is # of running jobs
         bits.append(len(self.get_running_jobs()))
-        #fourth field is # of queued jobs
+        # fourth field is # of queued jobs
         bits.append(len(self.get_queued_jobs()))
-        #fifth field is total # slots
+        # fifth field is total # slots
         bits.append(self.count_total_slots())
-        #sixth field is average job duration
+        # sixth field is average job duration
         bits.append(self.avg_job_duration())
-        #seventh field is average job wait time
+        # seventh field is average job wait time
         bits.append(self.avg_wait_time())
-        #last field is array of loads for hosts
+        # last field is array of loads for hosts
         arr = self.get_loads()
         # arr may be empty if there are no exec hosts
         if arr:
@@ -415,8 +414,8 @@ class SGELoadBalancer(LoadBalancer):
         self._cluster = None
         self._keep_polling = True
         self._visualizer = None
+        self._stat = None
         self.__last_cluster_mod_time = utils.get_utc_now()
-        self.stat = SGEStats()
         self.polling_interval = interval
         self.kill_after = kill_after
         self.longest_allowed_queue_time = wait_time
@@ -433,6 +432,13 @@ class SGELoadBalancer(LoadBalancer):
         if plot_stats:
             assert self.visualizer is not None
 
+    @property
+    def stat(self):
+        if not self._stat:
+            rtime = self.get_remote_time()
+            self._stat = SGEStats(remote_tzinfo=rtime.tzinfo)
+        return self._stat
+
     @property
     def visualizer(self):
         if not self._visualizer:
@@ -484,9 +490,12 @@ class SGELoadBalancer(LoadBalancer):
         and returns a datetime object with the master's time
         instead of fetching it from local machine, maybe inaccurate.
         """
-        utc = '\n'.join(self._cluster.master_node.ssh.execute('date --utc'))
-        dt = datetime.datetime.strptime(utc, "%a %b %d %H:%M:%S UTC %Y")
-        return dt.replace(tzinfo=iso8601.iso8601.UTC)
+        cmd = 'date --iso-8601=seconds'
+        date_str = '\n'.join(self._cluster.master_node.ssh.execute(cmd))
+        d = utils.iso_to_datetime_tuple(date_str)
+        if self._stat:
+            self._stat.remote_tzinfo = d.tzinfo
+        return d
 
     def get_qatime(self, now):
         """
@@ -620,21 +629,21 @@ class SGELoadBalancer(LoadBalancer):
             log.info("Avg job wait time: %d secs" % self.stat.avg_wait_time(),
                      extra=raw)
             log.info("Last cluster modification time: %s" %
-                     self.__last_cluster_mod_time.strftime("%Y-%m-%d %X"),
+                     self.__last_cluster_mod_time.strftime("%Y-%m-%d %X%z"),
                      extra=dict(__raw__=True))
-            #evaluate if nodes need to be added
+            # evaluate if nodes need to be added
             self._eval_add_node()
-            #evaluate if nodes need to be removed
+            # evaluate if nodes need to be removed
             self._eval_remove_node()
             if self.dump_stats or self.plot_stats:
                 self.stat.write_stats_to_csv(self.stats_file)
-            #call the visualizer
+            # call the visualizer
             if self.plot_stats:
                 try:
                     self.visualizer.graph_all()
                 except IOError, e:
                     raise exception.BaseException(str(e))
-            #evaluate if cluster should be terminated
+            # evaluate if cluster should be terminated
             if self.kill_cluster:
                 if self._eval_terminate_cluster():
                     log.info("Terminating cluster and exiting...")
@@ -682,7 +691,7 @@ class SGELoadBalancer(LoadBalancer):
             log.info("Adding node: below minimum (%d)" % self.min_nodes)
             need_to_add = self.min_nodes - num_nodes
         elif total_slots == 0:
-            #no slots, add one now
+            # no slots, add one now
             need_to_add = 1
         elif qw_slots > avail_slots:
             log.info("Queued jobs need more slots (%d) than available (%d)" %
