@@ -119,6 +119,11 @@ class InstanceNotRunning(AWSError):
         self.msg = "%s %s is not running (%s)" % (label, instance_id, state)
 
 
+class SubnetDoesNotExist(AWSError):
+    def __init__(self, subnet_id):
+        self.msg = "subnet does not exist: %s" % subnet_id
+
+
 class SecurityGroupDoesNotExist(AWSError):
     def __init__(self, sg_name):
         self.msg = "security group %s does not exist" % sg_name
@@ -129,6 +134,11 @@ class PlacementGroupDoesNotExist(AWSError):
         self.msg = "placement group %s does not exist" % pg_name
 
 
+class KeyPairAlreadyExists(AWSError):
+    def __init__(self, keyname):
+        self.msg = "keypair %s already exists" % keyname
+
+
 class KeyPairDoesNotExist(AWSError):
     def __init__(self, keyname):
         self.msg = "keypair %s does not exist" % keyname
@@ -206,11 +216,19 @@ class SpotHistoryError(AWSError):
         self.msg += "%s - %s" % (start, end)
 
 
+class PropagationException(AWSError):
+    pass
+
+
 class InvalidIsoDate(BaseException):
     def __init__(self, date):
         self.msg = "Invalid date specified: %s" % date
 
 
+class InvalidHostname(BaseException):
+    pass
+
+
 class ConfigError(BaseException):
     """Base class for all config related errors"""
 
@@ -543,7 +561,7 @@ Please terminate the cluster using:
 """
 
     def __init__(self, group):
-        tag = group.name.replace(static.SECURITY_GROUP_PREFIX + '-', '')
+        tag = group.name.replace(static.SECURITY_GROUP_PREFIX, '')
         states = ['pending', 'running', 'stopping', 'stopped']
         insts = group.connection.get_all_instances(
             filters={'instance-state-name': states,
